@@ -20,4 +20,8 @@ class Flask():
             @self.app.route(self.route)
             def nodecdnjsurl():
                 return "Works!"
-        else: print('[Flask] You must provide a leading slash before your route.')
\ No newline at end of file
+        else: 
+            print('[Flask] You must provide a leading slash before your route. ( ERROR on change_path() ) (default will be used)')
+            @self.app.route(self.route)
+            def nodecdnjsurl():
+                return "Works!"
\ No newline at end of file
